"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const archiver_1 = tslib_1.__importDefault(require("archiver"));
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const path_1 = require("path");
const build_1 = require("@cubesoft/nx-shared/src/utils/build/build");
const dependencies_1 = require("@cubesoft/nx-shared/src/utils/build/dependencies");
const package_internal_esbuild_1 = require("@cubesoft/nx-shared/src/utils/build/package-internal.esbuild");
const utils_1 = require("@cubesoft/nx-shared/src/utils/nx/utils");
const devkit_1 = require("@nx/devkit");
const file_utils_1 = require("../../utils/file-utils");
function buildExecuter(options, context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            yield build(options, context);
        }
        catch (error) {
            throw new Error(error);
        }
        return {
            success: true
        };
    });
}
exports.default = buildExecuter;
function build(options, context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const appRoot = (0, utils_1.getAbsoluteAppRoot)(context);
        const outputRoot = (0, utils_1.getAbsoluteOutputRoot)(context);
        const tsConfig = (0, path_1.join)(appRoot, 'tsconfig.app.json');
        yield (0, file_utils_1.deleteDirectory)(outputRoot);
        // Get all handlers as entry points for esbuild
        const entryPoints = (0, devkit_1.readJsonFile)((0, path_1.join)(appRoot, 'handlers.json')).entrypoints;
        for (const entryPoint of Object.keys(entryPoints)) {
            const outdir = (0, path_1.join)(outputRoot, (0, devkit_1.names)(entryPoint).fileName);
            const src = typeof entryPoints[entryPoint] === 'string'
                ? entryPoints[entryPoint]
                : entryPoints[entryPoint].src;
            const esbuildOptions = typeof entryPoints[entryPoint] === 'string'
                ? {}
                : entryPoints[entryPoint].esbuildOptions;
            const bundleNodeModules = typeof entryPoints[entryPoint] === 'string'
                ? false
                : entryPoints[entryPoint].bundleNodeModules;
            yield (0, build_1.build)(context, [(0, path_1.join)(appRoot, src)], outdir, tsConfig, Object.assign(Object.assign({}, esbuildOptions), { plugins: [yield (0, package_internal_esbuild_1.packageInternal)(context, tsConfig)] }), bundleNodeModules);
            yield (0, dependencies_1.resolveDependencies)((0, devkit_1.names)(entryPoint).fileName, outdir, tsConfig, outdir);
            if (options.installModules) {
                const args = ['install', '--production'];
                if (options.architecture) {
                    args.push(`--arch=${options.architecture}`);
                }
                if (options.platform) {
                    args.push(`--platform= ${options.platform}`);
                }
                (0, child_process_1.spawnSync)('npm', args, { cwd: outdir });
            }
            yield new Promise((resolve, reject) => {
                const output = (0, fs_1.createWriteStream)((0, path_1.join)(outdir, `handler.zip`));
                const archive = (0, archiver_1.default)('zip', {
                    zlib: { level: 6 }
                });
                archive.on('error', (error) => {
                    reject(error);
                });
                output.on('error', (error) => {
                    reject(error);
                });
                output.on('close', () => {
                    resolve();
                });
                archive.pipe(output);
                archive.glob('**', { dot: true, cwd: outdir });
                archive.finalize();
            });
        }
    });
}
//# sourceMappingURL=executor.js.map