"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const devkit_1 = require("@nx/devkit");
const eslint_1 = require("@nx/eslint");
const jest_1 = require("@nx/jest");
const versions_1 = require("../../utils/versions");
function normalizeOptions(tree, options) {
    const name = (0, devkit_1.names)(options.name).fileName;
    const projectDirectory = options.directory ? `${(0, devkit_1.names)(options.directory).fileName}/${name}` : name;
    const projectName = projectDirectory.replace(new RegExp('/', 'g'), '-');
    const projectRoot = `${(0, devkit_1.getWorkspaceLayout)(tree).appsDir}/${projectDirectory}`;
    const parsedTags = options.tags ? options.tags.split(',').map((s) => s.trim()) : [];
    return Object.assign(Object.assign({}, options), { projectName,
        projectRoot,
        projectDirectory,
        parsedTags });
}
function addFiles(tree, options) {
    const templateOptions = Object.assign(Object.assign(Object.assign({}, options), (0, devkit_1.names)(options.name)), { offsetFromRoot: (0, devkit_1.offsetFromRoot)(options.projectRoot), template: '' });
    (0, devkit_1.generateFiles)(tree, path.join(__dirname, 'files'), options.projectRoot, templateOptions);
}
function default_1(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const tasks = [];
        const normalizedOptions = normalizeOptions(tree, options);
        (0, devkit_1.addProjectConfiguration)(tree, normalizedOptions.projectName, {
            root: normalizedOptions.projectRoot,
            projectType: 'application',
            sourceRoot: `${normalizedOptions.projectRoot}/src`,
            targets: {
                build: {
                    executor: '@cubesoft/nx-lambda-build:build',
                    options: {
                        target: 'node16'
                    },
                    configurations: {
                        development: {},
                        production: {
                            fileReplacements: [
                                {
                                    replace: `${normalizedOptions.projectRoot}/src/environments/environment.ts`,
                                    with: `${normalizedOptions.projectRoot}/src/environments/environment.prod.ts`
                                }
                            ]
                        }
                    },
                    defaultConfiguration: 'production'
                }
            },
            tags: normalizedOptions.parsedTags
        });
        addFiles(tree, normalizedOptions);
        tasks.push(addDependencies(tree));
        tasks.push(yield (0, eslint_1.lintProjectGenerator)(tree, { project: options.name, skipFormat: true, linter: eslint_1.Linter.EsLint }));
        tasks.push(yield (0, jest_1.jestInitGenerator)(tree, {
            testEnvironment: 'node'
        }));
        yield (0, devkit_1.formatFiles)(tree);
        return (0, devkit_1.runTasksInSerial)(...tasks);
    });
}
exports.default = default_1;
function addDependencies(tree) {
    const dependencies = {};
    const devDependencies = {
        '@types/aws-lambda': versions_1.typesAwsLambdaVersion,
        depcheck: versions_1.depcheckVersion
    };
    return (0, devkit_1.addDependenciesToPackageJson)(tree, dependencies, devDependencies);
}
//# sourceMappingURL=generator.js.map