"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteDirectory = exports.copyDirectory = exports.readlink = exports.symlink = exports.lstat = exports.exists = exports.readDirectory = exports.createDirectory = exports.copyFile = exports.readJsonFile = exports.readFile = void 0;
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const path_1 = require("path");
function readFile(path) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!(yield exists(path))) {
            throw new Error(`Failed to open ${path}`);
        }
        return fs_1.promises.readFile(path);
    });
}
exports.readFile = readFile;
function readJsonFile(path) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return JSON.parse((yield readFile(path)).toString());
    });
}
exports.readJsonFile = readJsonFile;
function copyFile(src, dest) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield createDirectory((0, path_1.dirname)(dest));
        return fs_1.promises.copyFile(src, dest);
    });
}
exports.copyFile = copyFile;
function createDirectory(dir) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return fs_1.promises.mkdir(dir, { recursive: true });
    });
}
exports.createDirectory = createDirectory;
function readDirectory(dir) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return fs_1.promises.readdir(dir);
    });
}
exports.readDirectory = readDirectory;
function exists(path) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            yield fs_1.promises.access(path, fs_1.constants.F_OK);
            return true;
        }
        catch (_a) {
            return false;
        }
    });
}
exports.exists = exists;
function lstat(path) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return fs_1.promises.lstat(path);
    });
}
exports.lstat = lstat;
function symlink(src, dest) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return fs_1.promises.symlink(yield readlink(src), dest);
    });
}
exports.symlink = symlink;
function readlink(path) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return fs_1.promises.readlink(path);
    });
}
exports.readlink = readlink;
function copyDirectory(src, dest) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!(yield exists(dest))) {
            createDirectory(dest);
        }
        const entries = yield readDirectory(src);
        for (const entry of entries) {
            const srcPath = (0, path_1.join)(src.toString(), entry);
            const destPath = (0, path_1.join)(dest.toString(), entry);
            const stat = yield lstat(srcPath);
            if (stat.isFile()) {
                yield copyFile(srcPath, destPath);
            }
            else if (stat.isDirectory()) {
                yield copyDirectory(srcPath, destPath);
            }
            else if (stat.isSymbolicLink()) {
                yield symlink(srcPath, destPath);
            }
        }
    });
}
exports.copyDirectory = copyDirectory;
function deleteDirectory(path) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (yield exists(path)) {
            return fs_1.promises.rm(path, { recursive: true });
        }
        return;
    });
}
exports.deleteDirectory = deleteDirectory;
//# sourceMappingURL=file-utils.js.map